class Boot extends Phaser.Scene {
    constructor() {
        super('Boot');
    }

    preload() {
        let progressBar = this.add.graphics();
        let progressBox = this.add.graphics();
        let width = 320;
        let height = 50;
        let x = WIDTH_WINDOW / 2 - width / 2;
        let y = HEIGHT_WINDOW / 2 - height / 2;

        progressBox.fillStyle(0x222222, 0.8);
        progressBox.fillRect(x, y, 320, height);
        this.load.on('progress', function (value) {
            progressBar.clear();
            progressBar.fillStyle(0xffffff, 1);
            progressBar.fillRect(x + 10, y + 10, (width - 20) * value, height - 20);
        });
        this.load.on('complete', function () {
            progressBar.destroy();
            progressBox.destroy();
        });

        this.loadSprite('playLetter', 550, 150, 'buttons/');
        this.loadSprite('cancel', 550, 150, 'buttons/');
        this.loadSprite('add', 550, 150, 'buttons/');

        this.loadSprite('duel', 269, 262, 'buttons/');
        this.loadSprite('last', 269, 262, 'buttons/');
        this.loadSprite('team', 269, 262, 'buttons/');
        this.loadSprite('flag', 269, 262, 'buttons/');
        
        this.loadSprite('map', 269, 262, 'buttons/');
        this.loadSprite('play', 100, 100, 'buttons/');
        this.loadSprite('bin', 100, 100, 'buttons/');
        this.loadSprite('plus', 100, 100, 'buttons/');
        this.loadSprite('pencil', 100, 100, 'buttons/');

        this.loadSprite('shortRange', 300, 150, 'buttons/');
        this.loadSprite('mediumRange', 300, 150, 'buttons/');
        this.loadSprite('longRange', 300, 150, 'buttons/');

        this.loadSprite('shield0', 300, 150, 'buttons/');
        this.loadSprite('shield33', 300, 150, 'buttons/');
        this.loadSprite('shield66', 300, 150, 'buttons/');
        this.loadSprite('shield100', 300, 150, 'buttons/');

        this.loadSprite('myself', 300, 150, 'buttons/');
        this.loadSprite('enemyBot', 300, 150, 'buttons/');

        this.loadSprite('moveToward', 300, 150, 'buttons/');
        this.loadSprite('fleeFrom', 300, 150, 'buttons/');

        this.loadSprite('attackNode', 180, 190, 'nodes/');
        this.loadSprite('moveNode', 180, 190, 'nodes/');
        this.loadSprite('conditionNode', 180, 190, 'nodes/');


        this.loadImage('background');
        this.loadImage('bullet');
        this.loadImage('logoWaria');
        this.loadImage('attack', 'nodes/');
        this.loadImage('move', 'nodes/');
        this.loadImage('condition', 'nodes/');
    }

    create() {
        let style = {font: '200px stencil', fill: "#e2e2e2"};
        this.add.text(WIDTH_WINDOW / 2, HEIGHT_WINDOW / 3, "WARIA", style).setOrigin(0.5, 0.5);
        let btn = this.add.sprite(WIDTH_WINDOW / 2, (HEIGHT_WINDOW / 3) * 2, 'playLetter').setInteractive();
        //btn.setFrame(0);
        btn.on('pointerout', () => btn.setFrame(0));
        btn.on('pointerover', () => btn.setFrame(1));
        btn.on('pointerdown', () => this.clickPlay(btn));
    }

    clickPlay(btn) {
        btn.setFrame(2);
        console.log("Play");
        this.scene.start('Type');
    }

    loadSprite(name, width, height, folder = '') {
        this.load.spritesheet(name, 'assets/' + LANG + '/' + folder + name + '.png', {
            frameWidth: width,
            frameHeight: height
        });
    }

    loadImage(name, folder = '') {
        this.load.image(name, 'assets/' + LANG + '/' + folder + name + '.png');
    }
}