class HealthBar {
    constructor(scene, width, height, x, y, valueMax, color) {
        this.bar = new Phaser.GameObjects.Graphics(scene);

        this.width = width;
        this.height = height;
        this.valueMax = valueMax;
        this.value = valueMax;
        this.color = color;

        this.draw();

        this.setX(x);
        this.setY(y);
        scene.add.existing(this.bar);
    }

    decrease(amount) {
        this.value -= amount;

        let diff = 0;
        if (this.value < 0) {
            diff = -this.value;
            this.value = 0;
        }

        this.draw();

        return diff;
    }

    increase(amount) {
        this.value += amount;
        if (this.value > this.valueMax) {
            this.value = this.valueMax;
        }
        this.draw();
    }

    setX(x) {
        this.bar.setX(x - this.width / 2);
    }

    setY(y) {
        this.bar.setY(y);
    }

    draw() {
        this.bar.clear();

        //  BG
        this.bar.fillStyle(0x000000);
        this.bar.fillRect(0, 0, this.width, this.height);

        //  Health

        this.bar.fillStyle(0xffffff);
        this.bar.fillRect(2, 2, this.width - 4, this.height - 4);

        let percent = this.value / this.valueMax;

        if (percent < 1 / 3) {
            this.bar.fillStyle(0xff0000);
        } else {
            this.bar.fillStyle(this.color);
        }

        let d = Math.floor(percent * (this.width - 4));

        this.bar.fillRect(2, 2, d, this.height - 4);
    }

    destroy() {
        this.bar.destroy();
    }
}