class PlusNode extends Phaser.Scene {
    constructor(game, selected) {
        super('PlusNode');
        this.game = game;
        this.selected = selected;
    }

    create() {
        this.add.rectangle(0, 0, WIDTH_WINDOW, HEIGHT_WINDOW, 0x000000).setOrigin(0, 0).setAlpha(0.5);
        this.add.rectangle(0, HEIGHT_WINDOW / 2, WIDTH_WINDOW, HEIGHT_WINDOW / 2, 0x35363A).setOrigin(0, 0.5);
        this.createNode();
        this.createButton();
    }

    createNode() {
        let x = WIDTH_WINDOW / 2;
        let y = HEIGHT_WINDOW / 2;
        let diffX = WIDTH_WINDOW / 3;
        let diffY = HEIGHT_WINDOW / 10;
        let sizeText = diffY;

        let style = {font: sizeText.toString() + 'px stencil', fill: "#e2e2e2"};

        this.add.text(x - diffX, y - diffY, selectWord("ATTACK", "ATTAQUE"), style).setOrigin(0.5, 0.5);
        this.add.text(x, y - diffY, selectWord("MOVE", "DEPLACEMENT"), style).setOrigin(0.5, 0.5);
        this.add.text(x + diffX, y - diffY, selectWord("CONDITION", "CONDITION"), style).setOrigin(0.5, 0.5);

        let btn = this.add.sprite(x - diffX, y + diffY, 'attack').setOrigin(0.5, 0.5).setInteractive()
            .on('pointerdown', () => this.click('attack'));
        btn.displayHeight = diffY * 2;
        btn.scaleX = btn.scaleY;

        btn = this.add.sprite(x, y + diffY, 'move').setOrigin(0.5, 0.5).setInteractive()
            .on('pointerdown', () => this.click('move'));
        btn.displayHeight = diffY * 2;
        btn.scaleX = btn.scaleY;

        btn = this.add.sprite(x + diffX, y + diffY, 'condition').setOrigin(0.5, 0.5).setInteractive()
            .on('pointerdown', () => this.click('condition'));
        btn.displayHeight = diffY * 2;
        btn.scaleX = btn.scaleY;


    }

    click(action) {
        switch (action.toString()) {
            case 'attack':
                this.game.scene.add('AddNode', new AddAttack(this.game, this.selected))
                break;
            case 'move':
                this.game.scene.add('AddNode', new AddMove(this.game, this.selected))
                break;
            case 'condition':
                this.game.scene.add('AddNode', new AddCondition(this.game, this.selected))
                break;
        }
        this.scene.launch('AddNode');
        this.scene.stop('PlusNode');
        this.game.scene.remove('PlusNode');
    }

    createButton() {
        let x = WIDTH_WINDOW / 2;
        let y = HEIGHT_WINDOW - 100;
        let cancelBtn = this.add.image(x, y, 'cancel').setOrigin(0.5, 0.5).setInteractive();
        cancelBtn.on('pointerover', () => cancelBtn.setFrame(1));
        cancelBtn.on('pointerout', () => cancelBtn.setFrame(0));
        cancelBtn.on('pointerdown', () => this.cancel());
        cancelBtn.displayHeight = HEIGHT_WINDOW / 10;
        cancelBtn.scaleX = cancelBtn.scaleY;
    }

    cancel() {
        this.scene.resume('Game');
        this.scene.stop('PlusNode');
        this.game.scene.remove('PlusNode');
    }
}